OiRA

Help

1. Sagatavošanās
2. Iesaiste
3. Identifikācija + Novērtēšana
4. Rīcības plāns
5. Pārskats
6. Statuss 0%

# Pārskata lejupielāde un drukāšana

Iesakām vienmēr izdrukāt darba vides riska novērtējuma (pārskata) atjaunināto versiju.

Pārskats

- Format: Rich Text Format (.rtf)
- Contains: all the information and input provided by you throughout the risk assessment process.

Rīcības plāns

- Format: Office Open XML Workbook (.xlsx)
- Contains: main elements to effectively manage the risks at your workplace.

Risku pārskats

- Format: Portable Document Format (.pdf)
- Contains: an overview of the risks identified

Pārskats par veicamajiem pasākumiem

- Format: Portable Document Format (.pdf)
- Contains: an overview of the measures to be implemented.

Scroll to top
Back

## report-download.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More